@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef VTABLEHOOK_H
 #define VTABLEHOOK_H
@@ -21,13 +8,19 @@
 #include <QObject>
 #include <QSet>
 #include <QDebug>
-
+#include <QLoggingCategory>
 #include "global.h"
 
 #include <functional>
 
 DPP_BEGIN_NAMESPACE
 
+#ifndef QT_DEBUG
+inline Q_LOGGING_CATEGORY(vtableHook, "deepin.qpa.vtableHook", QtInfoMsg);
+#else
+inline Q_LOGGING_CATEGORY(vtableHook, "deepin.qpa.vtableHook");
+#endif
+
 static inline quintptr toQuintptr(void *ptr)
 {
     return *(quintptr*)ptr;
@@ -36,8 +29,12 @@ static inline quintptr toQuintptr(void *ptr)
 static inline int getVtableSize(quintptr **obj)
 {
     quintptr *begin = *obj;
-    while(*begin) ++begin;
-    return begin - *obj;
+    while (true) {
+      if ((int64_t)*begin == 0 or (int64_t)*begin < QSysInfo::WordSize)  // offset will grater than 8 bytes(64 bit)
+          break;
+       ++begin;
+    }
+    return begin - *obj + 2;  // for offset and rtti info
 }
 
 // http://refspecs.linux-foundation.org/cxxabi-1.83.html#vtable
@@ -57,11 +54,7 @@ public:
 
         quintptr *vfptr_t1 = reinterpret_cast<quintptr*>(resolve(vtable_symbol.constData()));
 
-        if (!vfptr_t1)
-            return nullptr;
-
-        // symbol address + 2 * sizeof(quintptr) = virtal table start address
-        return vfptr_t1 + 2;
+        return vfptr_t1 ? adjustToEntry(vfptr_t1) : nullptr;
     }
 
     static int getDestructFunIndex(quintptr **obj, std::function<void(void)> destoryObjFun);
@@ -126,7 +119,7 @@ public:
     {
         typedef QtPrivate::FunctionPointer<Fun1> FunInfo1;
         // 检查析构函数是否为虚
-        class OverrideDestruct : public FunInfo1::Object { ~OverrideDestruct() override;};
+        class OverrideDestruct : public FunInfo1::Object { ~OverrideDestruct() override;}; //TODO: we can use std::has_virtual_destructor
 
         if (!ensureVtable((void*)t1, std::bind(&_destory_helper<typename FunInfo1::Object>, t1))) {
             return false;
@@ -208,7 +201,7 @@ public:
             static StdFunType fun = f;
             static bool initialized = false;
             if (initialized && check) {
-                qWarning("The StdFunWrap is dirty! Don't use std::bind(use lambda functions).");
+                qCWarning(vtableHook, "The StdFunWrap is dirty! Don't use std::bind(use lambda functions).");
             }
             initialized = true;
             return fun;
@@ -247,7 +240,7 @@ public:
      * \note 因为如果分开写为&B::foo1和&C::foo2的话，指针转换内部会记录多张虚表，重载多份析构函数，可能导致最开始的部分无法正常析构！
      */
     template<typename Fun1, typename Fun2>
-    static bool overrideVfptrFun(const typename QtPrivate::FunctionPointer<Fun1>::Object *t1, Fun1 fun1, Fun2 fun2)
+    static bool overrideVfptrFun(const typename QtPrivate::FunctionPointer<Fun1>::Object *t1, Fun1 fun1, Fun2 fun2) //THIS
     {
         typedef QtPrivate::FunctionPointer<Fun1> FunInfo1;
         // 检查析构函数是否为虚
@@ -324,7 +317,7 @@ public:
         rvf.oldFun = resetVfptrFun((void*)obj, fun_offset);
 
         if (!rvf.oldFun) {
-            qWarning() << "Reset the function failed, object:" << obj;
+            qCWarning(vtableHook) << "Reset the function failed, object address:" << static_cast<void *>(obj);
             abort();
         }
 
@@ -337,6 +330,22 @@ private:
     static bool clearGhostVtable(const void *obj);
     static void clearAllGhostVtable();
 
+    template <typename T>
+    static T adjustToTop(T obj)  // vtableTop: vtable start address, Usually refers to offset_to_top
+    {
+        // this function should'n be called when entry is parent entry
+        using fundamentalType = typename std::remove_cv<typename std::remove_pointer<T>::type>::type;
+        return obj - static_cast<fundamentalType>(2);  // vtable start address  = vtable entry - 2
+    }
+
+    template <typename T>
+    static T adjustToEntry(T obj)  // vtableEntry: is located after rtti in the virtual table
+    {
+        // this function should'n be called when entry is parent entry
+        using fundamentalType = typename std::remove_cv<typename std::remove_pointer<T>::type>::type;
+        return obj + static_cast<fundamentalType>(2);  // vtable entry = vtable start address + 2
+    }
+    
     template<typename T>
     static void _destory_helper(const T *obj) {
         delete obj;
