@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Uniontech Technology Co., Ltd.
- *
- * Author:     WangPeng <wangpenga@uniontech.com>
- *
- * Maintainer: AlexOne  <993381@qq.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 0217 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef DNOTITLEBARWINDOWHELPER_WL_H
 #define DNOTITLEBARWINDOWHELPER_WL_H
 
@@ -42,6 +26,7 @@ public:
     ~DNoTitlebarWlWindowHelper();
 
     static void setWindowProperty(QWindow *window, const char *name, const QVariant &value);
+    static void requestByWindowProperty(QWindow *window, const char *name);
     static void popupSystemWindowMenu(quintptr wid);
 
 private slots:
@@ -49,7 +34,7 @@ private slots:
     Q_SLOT void updateEnableSystemMoveFromProperty();
 
 private:
-    static bool windowEvent(QWindow *w, QEvent *event, DNoTitlebarWlWindowHelper *self);
+    static bool windowEvent(QWindow *w, QEvent *event);
     bool isEnableSystemMove();
     static void startMoveWindow(QWindow *window);
 
