@@ -194,6 +194,9 @@ void DWaylandIntegration::initialize()
     // 增加rect的属性，保存主屏的具体坐标，不依靠其name判断(根据name查找对应的屏幕时概率性出错，根据主屏的rect确定哪一个QScreen才是主屏)
     dXSettings->globalSettings()->registerCallbackForProperty(XSETTINGS_PRIMARY_MONITOR_RECT, onPrimaryRectChanged, reinterpret_cast<void*>(XSettingType::Dde_PrimaryMonitorRect));
 
+    //初始化时应该设一次主屏，防止应用启动时主屏闪变
+    onPrimaryRectChanged(nullptr, XSETTINGS_PRIMARY_MONITOR_RECT, QVariant(), reinterpret_cast<void*>(XSettingType::Dde_PrimaryMonitorRect));
+
     QTimer *m_delayTimer = new QTimer;
     m_delayTimer->setInterval(10);
     m_delayTimer->setSingleShot(true);
