@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2020 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef DPLATFORMNATIVEINTERFACE_H
 #define DPLATFORMNATIVEINTERFACE_H
@@ -50,13 +37,24 @@ public:
 
     static bool setEnableNoTitlebar(QWindow *window, bool enable);
     static bool isEnableNoTitlebar(QWindow *window);
-    static bool setWindowRadius(QWindow *window, int value);
+
+    static void setWindowRadius(QWindow *window, int value);
+    static void setBorderColor(QWindow *window, const QColor &value);
+    static void setShadowColor(QWindow *window, const QColor &value);
+    static void setShadowRadius(QWindow *window, int value);
+    static void setShadowOffset(QWindow *window, const QPoint &value);
+    static void setBorderWidth(QWindow *window, int value);
+    static void setWindowEffect(QWindow *window, const QVariant &value);
+    static void setWindowStartUpEffect(QWindow *window, const QVariant &value);
+
     static void setWindowProperty(QWindow *window, const char *name, const QVariant &value);
     static void popupSystemWindowMenu(quintptr wid);
     static bool enableDwayland(QWindow *window);
     static bool isEnableDwayland(const QWindow *window);
     static void splitWindowOnScreen(WId wid, quint32 type);
+    static void splitWindowOnScreenByType(WId wid, quint32 position, quint32 type);
     static bool supportForSplittingWindow(WId wid);
+    static bool supportForSplittingWindowByType(quint32 wid, quint32 screenSplittingType);
 };
 
 DPP_END_NAMESPACE
