@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dxcbwmsupport.h"
 #include "dplatformintegration.h"
@@ -54,6 +41,8 @@ void DXcbWMSupport::updateWMName(bool emitSignal)
     _net_wm_deepin_blur_region_rounded_atom = Utility::internAtom(QT_STRINGIFY(_NET_WM_DEEPIN_BLUR_REGION_ROUNDED), false);
     _net_wm_deepin_blur_region_mask = Utility::internAtom(QT_STRINGIFY(_NET_WM_DEEPIN_BLUR_REGION_MASK), false);
     _kde_net_wm_blur_rehind_region_atom = Utility::internAtom(QT_STRINGIFY(_KDE_NET_WM_BLUR_BEHIND_REGION), false);
+    _deepin_wallpaper = Utility::internAtom(QT_STRINGIFY(_DEEPIN_WALLPAPER), false);
+    _deepin_wallpaper_shared_key = Utility::internAtom(QT_STRINGIFY(_DEEPIN_WALLPAPER_SHARED_MEMORY), false);
     _deepin_no_titlebar = Utility::internAtom(QT_STRINGIFY(_DEEPIN_NO_TITLEBAR), false);
     _deepin_scissor_window = Utility::internAtom(QT_STRINGIFY(_DEEPIN_SCISSOR_WINDOW), false);
 
@@ -65,7 +54,7 @@ void DXcbWMSupport::updateWMName(bool emitSignal)
     xcb_get_property_reply_t *reply =
         xcb_get_property_reply(xcb_connection,
             xcb_get_property_unchecked(xcb_connection, false, root,
-                             DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_NET_SUPPORTING_WM_CHECK),
+                             DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_NET_SUPPORTING_WM_CHECK)),
                              XCB_ATOM_WINDOW, 0, 1024), NULL);
 
     if (reply && reply->format == 32 && reply->type == XCB_ATOM_WINDOW) {
@@ -75,10 +64,10 @@ void DXcbWMSupport::updateWMName(bool emitSignal)
             xcb_get_property_reply_t *windowManagerReply =
                 xcb_get_property_reply(xcb_connection,
                     xcb_get_property_unchecked(xcb_connection, false, windowManager,
-                                     DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_NET_WM_NAME),
-                                     DPlatformIntegration::xcbConnection()->atom(QXcbAtom::UTF8_STRING), 0, 1024), NULL);
+                                     DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_NET_WM_NAME)),
+                                     DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(UTF8_STRING)), 0, 1024), NULL);
             if (windowManagerReply && windowManagerReply->format == 8
-                    && windowManagerReply->type == DPlatformIntegration::xcbConnection()->atom(QXcbAtom::UTF8_STRING)) {
+                    && windowManagerReply->type == DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(UTF8_STRING))) {
                 m_wmName = QString::fromUtf8((const char *)xcb_get_property_value(windowManagerReply), xcb_get_property_value_length(windowManagerReply));
             }
 
@@ -109,7 +98,7 @@ void DXcbWMSupport::updateNetWMAtoms()
 
     do {
         xcb_get_property_cookie_t cookie = xcb_get_property(xcb_connection, false, root,
-                                                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_NET_SUPPORTED),
+                                                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_NET_SUPPORTED)),
                                                             XCB_ATOM_ATOM, offset, 1024);
         xcb_get_property_reply_t *reply = xcb_get_property_reply(xcb_connection, cookie, NULL);
         if (!reply)
@@ -134,6 +123,7 @@ void DXcbWMSupport::updateNetWMAtoms()
     updateHasBlurWindow();
     updateHasNoTitlebar();
     updateHasScissorWindow();
+    updateWallpaperEffect();
 }
 
 void DXcbWMSupport::updateRootWindowProperties()
@@ -164,7 +154,7 @@ void DXcbWMSupport::updateHasBlurWindow()
     bool hasBlurWindow((m_isDeepinWM && isSupportedByWM(_net_wm_deepin_blur_region_rounded_atom))
                        || (m_isKwin && isContainsForRootWindow(_kde_net_wm_blur_rehind_region_atom)));
     // 当窗口visual不支持alpha通道时，也等价于不支持窗口背景模糊
-    hasBlurWindow = hasBlurWindow && getHasWindowAlpha() && hasComposite();
+    hasBlurWindow = hasBlurWindow && getHasWindowAlpha();
 
     if (m_hasBlurWindow == hasBlurWindow)
         return;
@@ -201,7 +191,7 @@ void DXcbWMSupport::updateHasComposite()
         DPlatformIntegration::xcbConnection()->primaryVirtualDesktop()->m_compositingActive = hasComposite;
     } else {
         //stage2: fallback to check selection owner
-        xcb_get_selection_owner_cookie_t cookit = xcb_get_selection_owner(xcb_connection, DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_NET_WM_CM_S0));
+        xcb_get_selection_owner_cookie_t cookit = xcb_get_selection_owner(xcb_connection, DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_NET_WM_CM_S0)));
         xcb_get_selection_owner_reply_t *reply = xcb_get_selection_owner_reply(xcb_connection, cookit, NULL);
         if (!reply)
             return;
@@ -243,6 +233,18 @@ void DXcbWMSupport::updateHasScissorWindow()
     emit hasScissorWindowChanged(m_hasScissorWindow);
 }
 
+void DXcbWMSupport::updateWallpaperEffect()
+{
+    bool hasWallpaperEffect(net_wm_atoms.contains(_deepin_wallpaper));
+
+    if (m_hasWallpaperEffect == hasWallpaperEffect)
+        return;
+
+    m_hasWallpaperEffect = hasWallpaperEffect;
+
+    emit hasWallpaperEffectChanged(hasWallpaperEffect);
+}
+
 qint8 DXcbWMSupport::getHasWindowAlpha() const
 {
     if (m_windowHasAlpha < 0) {
@@ -297,6 +299,14 @@ bool DXcbWMSupport::connectHasNoTitlebarChanged(QObject *object, std::function<v
     return QObject::connect(globalXWMS, &DXcbWMSupport::hasNoTitlebarChanged, object, slot);
 }
 
+bool DXcbWMSupport::connectHasWallpaperEffectChanged(QObject *object, std::function<void ()> slot)
+{
+    if (!object)
+        return QObject::connect(globalXWMS, &DXcbWMSupport::hasWallpaperEffectChanged, slot);
+
+    return QObject::connect(globalXWMS, &DXcbWMSupport::hasWallpaperEffectChanged, object, slot);
+}
+
 bool DXcbWMSupport::connectWindowListChanged(QObject *object, std::function<void ()> slot)
 {
     if (!object)
@@ -514,6 +524,11 @@ bool DXcbWMSupport::hasWindowAlpha() const
     return m_hasComposite && getHasWindowAlpha();
 }
 
+bool DXcbWMSupport::hasWallpaperEffect() const
+{
+    return m_hasWallpaperEffect;
+}
+
 bool DXcbWMSupport::Global::hasBlurWindow()
 {
     return  DXcbWMSupport::instance()->hasBlurWindow();
@@ -537,6 +552,11 @@ bool DXcbWMSupport::Global::hasWindowAlpha()
     return DXcbWMSupport::instance()->hasWindowAlpha();
 }
 
+bool DXcbWMSupport::Global::hasWallpaperEffect()
+{
+    return  DXcbWMSupport::instance()->hasWallpaperEffect();
+}
+
 QString DXcbWMSupport::Global::windowManagerName()
 {
     return DXcbWMSupport::instance()->windowManagerName();
