@@ -1,41 +1,6 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the plugins of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #ifndef QXCBNATIVEINTERFACE_H
 #define QXCBNATIVEINTERFACE_H
@@ -53,6 +18,7 @@ class QWidget;
 class QXcbScreen;
 class QXcbConnection;
 class QXcbNativeInterfaceHandler;
+class QDBusMenuConnection;
 
 class Q_XCB_EXPORT QXcbNativeInterface : public QPlatformNativeInterface
 {
@@ -72,28 +38,29 @@ public:
         RootWindow,
         ScreenSubpixelType,
         ScreenAntialiasingEnabled,
+        NoFontHinting,
         AtspiBus,
         CompositingEnabled
     };
 
     QXcbNativeInterface();
 
-    void *nativeResourceForIntegration(const QByteArray &resource) override;
-    void *nativeResourceForContext(const QByteArray &resourceString, QOpenGLContext *context) override;
-    void *nativeResourceForScreen(const QByteArray &resource, QScreen *screen) override;
-    void *nativeResourceForWindow(const QByteArray &resourceString, QWindow *window) override;
-    void *nativeResourceForBackingStore(const QByteArray &resource, QBackingStore *backingStore) override;
+    void *nativeResourceForIntegration(const QByteArray &resource) Q_DECL_OVERRIDE;
+    void *nativeResourceForContext(const QByteArray &resourceString, QOpenGLContext *context) Q_DECL_OVERRIDE;
+    void *nativeResourceForScreen(const QByteArray &resource, QScreen *screen) Q_DECL_OVERRIDE;
+    void *nativeResourceForWindow(const QByteArray &resourceString, QWindow *window) Q_DECL_OVERRIDE;
+    void *nativeResourceForBackingStore(const QByteArray &resource, QBackingStore *backingStore) Q_DECL_OVERRIDE;
 #ifndef QT_NO_CURSOR
-    void *nativeResourceForCursor(const QByteArray &resource, const QCursor &cursor) override;
+    void *nativeResourceForCursor(const QByteArray &resource, const QCursor &cursor) Q_DECL_OVERRIDE;
 #endif
 
-    NativeResourceForIntegrationFunction nativeResourceFunctionForIntegration(const QByteArray &resource) override;
-    NativeResourceForContextFunction nativeResourceFunctionForContext(const QByteArray &resource) override;
-    NativeResourceForScreenFunction nativeResourceFunctionForScreen(const QByteArray &resource) override;
-    NativeResourceForWindowFunction nativeResourceFunctionForWindow(const QByteArray &resource) override;
-    NativeResourceForBackingStoreFunction nativeResourceFunctionForBackingStore(const QByteArray &resource) override;
+    NativeResourceForIntegrationFunction nativeResourceFunctionForIntegration(const QByteArray &resource) Q_DECL_OVERRIDE;
+    NativeResourceForContextFunction nativeResourceFunctionForContext(const QByteArray &resource) Q_DECL_OVERRIDE;
+    NativeResourceForScreenFunction nativeResourceFunctionForScreen(const QByteArray &resource) Q_DECL_OVERRIDE;
+    NativeResourceForWindowFunction nativeResourceFunctionForWindow(const QByteArray &resource) Q_DECL_OVERRIDE;
+    NativeResourceForBackingStoreFunction nativeResourceFunctionForBackingStore(const QByteArray &resource) Q_DECL_OVERRIDE;
 
-    QFunctionPointer platformFunction(const QByteArray &function) const override;
+    QFunctionPointer platformFunction(const QByteArray &function) const Q_DECL_OVERRIDE;
 
     inline const QByteArray &genericEventFilterType() const { return m_genericEventFilterType; }
 
@@ -129,7 +96,7 @@ private:
 
     const QByteArray m_genericEventFilterType;
 
-    xcb_atom_t m_sysTraySelectionAtom = XCB_ATOM_NONE;
+    xcb_atom_t m_sysTraySelectionAtom;
 
     static QXcbScreen *qPlatformScreenForWindow(QWindow *window);
 
