@@ -1,35 +1,6 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the QtGui module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL21$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #ifndef QXCBDRAG_H
 #define QXCBDRAG_H
@@ -68,14 +39,14 @@ public:
     QXcbDrag(QXcbConnection *c);
     ~QXcbDrag();
 
-    virtual QMimeData *platformDropData() Q_DECL_OVERRIDE;
-    bool eventFilter(QObject *o, QEvent *e) Q_DECL_OVERRIDE;
+    QMimeData *platformDropData() override;
+    bool eventFilter(QObject *o, QEvent *e) override;
 
-    void startDrag() Q_DECL_OVERRIDE;
-    void cancel() Q_DECL_OVERRIDE;
-    void move(const QPoint &globalPos) Q_DECL_OVERRIDE;
-    void drop(const QPoint &globalPos) Q_DECL_OVERRIDE;
-    void endDrag() Q_DECL_OVERRIDE;
+    void startDrag() override;
+    void cancel() override;
+    void move(const QPoint &globalPos) override;
+    void drop(const QPoint &globalPos) override;
+    void endDrag() override;
 
     void handleEnter(QPlatformWindow *window, const xcb_client_message_event_t *event, xcb_window_t proxy = 0);
     void handlePosition(QPlatformWindow *w, const xcb_client_message_event_t *event);
@@ -87,13 +58,13 @@ public:
     void handleFinished(const xcb_client_message_event_t *event);
 
     bool dndEnable(QXcbWindow *win, bool on);
-    bool ownsDragObject() const Q_DECL_OVERRIDE;
+    bool ownsDragObject() const override;
 
     void updatePixmap();
     xcb_timestamp_t targetTime() { return target_time; }
 
 protected:
-    void timerEvent(QTimerEvent* e) Q_DECL_OVERRIDE;
+    void timerEvent(QTimerEvent* e) override;
 
 private:
     friend class QXcbDropData;
@@ -153,6 +124,7 @@ private:
         QPointer<QDrag> drag;
         QTime time;
     };
+    friend class QTypeInfo<Transaction>;
     QVector<Transaction> transactions;
 
     int transaction_expiry_timer;
@@ -161,6 +133,7 @@ private:
     int findTransactionByTime(xcb_timestamp_t timestamp);
     xcb_window_t findRealWindow(const QPoint & pos, xcb_window_t w, int md, bool ignoreNonXdndAwareWindows);
 };
+Q_DECLARE_TYPEINFO(QXcbDrag::Transaction, Q_MOVABLE_TYPE);
 
 #endif // QT_NO_DRAGANDDROP
 
