@@ -3,7 +3,6 @@
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "utility.h"
-#include "qxcbintegration.h"
 #include "qxcbconnection.h"
 #include "qxcbscreen.h"
 
@@ -14,7 +13,12 @@
 #include <QPainter>
 #include <QCursor>
 #include <QDebug>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QtX11Extras/QX11Info>
+#endif
+
 #include <QGuiApplication>
 #include <qpa/qplatformwindow.h>
 #include <qpa/qplatformcursor.h>
@@ -224,7 +228,6 @@ void Utility::setFrameExtents(WId wid, const QMargins &margins)
     data[1] = int32_t(margins.right());
     data[2] = int32_t(margins.top());
     data[3] = int32_t(margins.bottom());
-
     xcb_change_property_checked(QX11Info::connection(), XCB_PROP_MODE_REPLACE, xcb_window_t(wid), frameExtents, XCB_ATOM_CARDINAL, 32, 4, data);
 }
 
@@ -233,14 +236,13 @@ static QVector<xcb_rectangle_t> qregion2XcbRectangles(const QRegion &region)
     QVector<xcb_rectangle_t> rectangles;
 
     rectangles.reserve(region.rectCount());
-
-    for (const QRect &rect : region.rects()) {
+    for (auto rect = region.cbegin(); rect != region.cend(); ++rect) {
         xcb_rectangle_t r;
 
-        r.x = rect.x();
-        r.y = rect.y();
-        r.width = rect.width();
-        r.height = rect.height();
+        r.x = rect->x();
+        r.y = rect->y();
+        r.width = rect->width();
+        r.height = rect->height();
 
         rectangles << r;
     }
@@ -286,13 +288,14 @@ void Utility::setShapePath(quint32 WId, const QPainterPath &path, bool onlyInput
     QVector<xcb_rectangle_t> rectangles;
 
     foreach(const QPolygonF &polygon, path.toFillPolygons()) {
-        foreach(const QRect &area, QRegion(polygon.toPolygon()).rects()) {
+        QRegion region(polygon.toPolygon());
+        for (auto area = region.cbegin(); area != region.cend(); ++area) {
             xcb_rectangle_t rectangle;
 
-            rectangle.x = area.x();
-            rectangle.y = area.y();
-            rectangle.width = area.width();
-            rectangle.height = area.height();
+            rectangle.x = area->x();
+            rectangle.y = area->y();
+            rectangle.width = area->width();
+            rectangle.height = area->height();
 
             rectangles.append(std::move(rectangle));
         }
@@ -402,11 +405,9 @@ bool Utility::setWindowCursor(quint32 WId, Utility::CornerEdge ce)
 QRegion Utility::regionAddMargins(const QRegion &region, const QMargins &margins, const QPoint &offset)
 {
     QRegion tmp;
-
-    for (const QRect &rect : region.rects()) {
-        tmp += rect.translated(offset) + margins;
+    for(auto rect = region.cbegin(); rect != region.cend(); ++rect) {
+        tmp += rect->translated(offset) + margins;
     }
-
     return tmp;
 }
 
@@ -556,8 +557,9 @@ bool Utility::blurWindowBackground(const quint32 WId, const QVector<BlurArea> &a
                 path.addRoundedRect(area.x, area.y, area.width, area.height, area.xRadius, area.yRaduis);
 
                 foreach(const QPolygonF &polygon, path.toFillPolygons()) {
-                    foreach(const QRect &area, QRegion(polygon.toPolygon()).rects()) {
-                        rects << area.x() << area.y() << area.width() << area.height();
+                    QRegion region(polygon.toPolygon());
+                    for(auto area = region.cbegin(); area != region.cend(); ++area) {
+                        rects << area->x() << area->y() << area->width() << area->height();
                     }
                 }
             }
@@ -610,8 +612,9 @@ bool Utility::blurWindowBackgroundByPaths(const quint32 WId, const QList<QPainte
 
         foreach (const QPainterPath &path, paths) {
             foreach(const QPolygonF &polygon, path.toFillPolygons()) {
-                foreach(const QRect &area, QRegion(polygon.toPolygon()).rects()) {
-                    rects << area.x() << area.y() << area.width() << area.height();
+                QRegion region(polygon.toPolygon());
+                for(auto area = region.cbegin(); area != region.cend(); ++area) {
+                    rects << area->x() << area->y() << area->width() << area->height();
                 }
             }
         }
@@ -632,10 +635,9 @@ bool Utility::blurWindowBackgroundByImage(const quint32 WId, const QRect &blurRe
 
     area.reserve(5);
     area << blurRect.x() << blurRect.y() << blurRect.width() << blurRect.height() << maskImage.bytesPerLine();
-
-    array.reserve(area.size() * sizeof(qint32) / sizeof(char) * area.size() + maskImage.byteCount());
+    array.reserve(area.size() * sizeof(qint32) / sizeof(char) * area.size() + maskImage.sizeInBytes());
     array.append((const char*)area.constData(), sizeof(qint32) / sizeof(char) * area.size());
-    array.append((const char*)maskImage.constBits(), maskImage.byteCount());
+    array.append((const char*)maskImage.constBits(), maskImage.sizeInBytes());
 
     clearWindowProperty(WId, DXcbWMSupport::instance()->_net_wm_deepin_blur_region_rounded_atom);
     setWindowProperty(WId, DXcbWMSupport::instance()->_net_wm_deepin_blur_region_mask,
@@ -693,13 +695,13 @@ Utility::QtMotifWmHints Utility::getMotifWmHints(quint32 WId)
     QtMotifWmHints hints;
 
     xcb_get_property_cookie_t get_cookie =
-        xcb_get_property_unchecked(xcb_connect, 0, WId, DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS),
-                                   DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS), 0, 20);
+        xcb_get_property_unchecked(xcb_connect, 0, WId, DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)),
+                                   DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)), 0, 20);
 
     xcb_get_property_reply_t *reply =
         xcb_get_property_reply(xcb_connect, get_cookie, NULL);
 
-    if (reply && reply->format == 32 && reply->type == DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS)) {
+    if (reply && reply->format == 32 && reply->type == DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS))) {
         hints = *((QtMotifWmHints *)xcb_get_property_value(reply));
     } else {
         hints.flags = 0L;
@@ -731,8 +733,8 @@ void Utility::setMotifWmHints(quint32 WId, Utility::QtMotifWmHints hints)
         Q_XCB_CALL2(xcb_change_property(DPlatformIntegration::xcbConnection()->xcb_connection(),
                                         XCB_PROP_MODE_REPLACE,
                                         WId,
-                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS),
-                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS),
+                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)),
+                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)),
                                         32,
                                         5,
                                         &hints), c);
@@ -740,8 +742,8 @@ void Utility::setMotifWmHints(quint32 WId, Utility::QtMotifWmHints hints)
         xcb_change_property(DPlatformIntegration::xcbConnection()->xcb_connection(),
                             XCB_PROP_MODE_REPLACE,
                             WId,
-                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS),
-                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS),
+                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)),
+                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)),
                             32,
                             5,
                             &hints);
@@ -749,11 +751,11 @@ void Utility::setMotifWmHints(quint32 WId, Utility::QtMotifWmHints hints)
     } else {
 #ifdef Q_XCB_CALL2
         Q_XCB_CALL2(xcb_delete_property(DPlatformIntegration::xcbConnection()->xcb_connection(), WId,
-                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS)),
+                                        DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS))),
                                         DPlatformIntegration::xcbConnection()->xcb_connection());
 #else
         xcb_delete_property(DPlatformIntegration::xcbConnection()->xcb_connection(), WId,
-                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::_MOTIF_WM_HINTS));
+                            DPlatformIntegration::xcbConnection()->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_MOTIF_WM_HINTS)));
 #endif
     }
 }
@@ -858,8 +860,8 @@ quint32 Utility::createGroupWindow()
     xcb_change_property(connection->xcb_connection(),
                         XCB_PROP_MODE_REPLACE,
                         group_leader,
-                        connection->atom(QXcbAtom::_NET_WM_NAME),
-                        connection->atom(QXcbAtom::UTF8_STRING),
+                        connection->atom(QXcbAtom::D_QXCBATOM_WRAPPER(_NET_WM_NAME)),
+                        connection->atom(QXcbAtom::D_QXCBATOM_WRAPPER(UTF8_STRING)),
                         8,
                         ba.length(),
                         ba.constData());
@@ -867,7 +869,7 @@ quint32 Utility::createGroupWindow()
     xcb_change_property(connection->xcb_connection(),
                         XCB_PROP_MODE_REPLACE,
                         group_leader,
-                        connection->atom(QXcbAtom::WM_CLIENT_LEADER),
+                        connection->atom(QXcbAtom::D_QXCBATOM_WRAPPER(WM_CLIENT_LEADER)),
                         XCB_ATOM_WINDOW,
                         32,
                         1,
@@ -880,7 +882,7 @@ quint32 Utility::createGroupWindow()
         xcb_change_property(connection->xcb_connection(),
                             XCB_PROP_MODE_REPLACE,
                             group_leader,
-                            connection->atom(QXcbAtom::SM_CLIENT_ID),
+                            connection->atom(QXcbAtom::D_QXCBATOM_WRAPPER(SM_CLIENT_ID)),
                             XCB_ATOM_STRING,
                             8,
                             session.length(),
